from django.utils import simplejson
from django.contrib.auth import authenticate, login
from django.contrib.auth.decorators import user_passes_test

from .forms import LoginForm


def log_in(request, form):
    form = LoginForm(form)
    success = False
    if form.is_valid():
        user = authenticate(username=form.cleaned_data['username'],
            password=form.cleaned_data['password'])
        if user is not None:
            if user.is_active:
                login(request, user)
                success = True

    return simplejson.dumps({
        'success': success
    })



from django import forms
from django.forms import ModelForm

from suave.models import Page
from collection.models import Product, Category


class LoginForm(forms.Form):
    username = forms.CharField(max_length=255, label=u'Username')
    password = forms.CharField(widget=forms.PasswordInput, label=u'Password')


class ProductForm(ModelForm):
    class Meta:
        model = Product
        exclude = ('in_date', 'num_views', 'slug')


class ProductTableRow(ModelForm):
    class Meta:
        model = Product
        fields = ('featured', 'sold', 'category',)


class PageForm(ModelForm):
    class Meta:
        model = Page
        exclude = ('identifier', 'url', 'template_override',)


class CategoryForm(ModelForm):
    class Meta:
        model = Category
        #exclude = ('identifier', 'url', 'template_override',)



import os
import hashlib
from uuid import uuid4

from django.db.models import Q
from django.conf import settings


def random_filename(directory, ext=None, root=settings.MEDIA_ROOT):
    """Gets a random untaken filename based on a root, a subdirectory path,
    returns the full path, the filename, and the subdirectory + filename.
    """
    path = ''
    if not os.path.exists(root + directory):
        os.mkdir(root + directory)
    while path == '' or os.path.exists(path):
        filename = hashlib.sha1(str(uuid4())).hexdigest()
        if ext:
            filename += '.' + ext
        path = '%s%s%s' % (
            root,
            directory,
            filename
        )
    return path, filename, directory + filename


def qsearch(qs, search_string):
    qs = qs.filter(
        Q(name__icontains=search_string)
            | Q(reference__icontains=search_string)
            | Q(id__icontains=search_string)
            | Q(description__icontains=search_string)
    )
    return qs



from setuptools import setup, find_packages

NAME = 'links-luxuryadmin'

setup(
    name=NAME,
    version="0.1.7",
    description='Luxury Admin for Django',
    long_description=open('README.md').read(),
    url='http://www.linkscreative.co.uk/',
    author='James Cleveland',
    author_email='jamescleveland@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    license="LICENSE.txt",
    package_data={
        '': ['*.txt', '*.rst']
    }
)
